Module style

Module style 

Shared theme-aware UI styling helpers and status-display helpers. Theme-aware semantic color helpers for Agentty’s terminal UI.

Modules

palette
Shared semantic color tokens for the terminal UI.

Structs

ThemePalette
Complete set of semantic colors resolved for one UI theme.

Functions

border_style
Returns the common border style for framed panels and table widgets.
forge_indicator_color
Returns the terminal color for a forge indicator suffix.
set_active_theme
Sets the process-wide active color theme used by semantic palette tokens.
status_color
Returns the terminal color used for one session status label.
status_icon
Returns the icon used for one session status indicator.