App module router.
This parent module intentionally exposes child modules and re-exports app orchestration types and functions.
Re-exports
pub use core::agentty_home;
Modules
- session_
state - Compatibility re-exports for session snapshot state.
Structs
- App
- Stores application state and coordinates session/project workflows.
- AppServices
- Shared app dependencies used by managers and background workflows.
- Project
Manager - Project domain state and git status tracking for the active project.
- Session
Manager - Session domain state and worker orchestration state.
- Session
State - Holds all in-memory state related to session listing and refresh tracking.
- Settings
Manager - Manages user-configurable application settings.
- TabManager
- Manages selection state for top-level tabs.
Enums
- AppError
- Typed error returned by top-level app orchestration operations.
- Session
Error - Typed error returned by session-layer workflow operations.
- Tab
- Available top-level tabs in list mode.
- Update
Status - Background auto-update progress state for the status bar.
Constants
- AGENTTY_
WT_ DIR - Relative directory name used for session git worktrees within the
agenttyhome directory.